/**
 * Retrieves the translation of text.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-i18n/
 */
import { __ } from '@wordpress/i18n';

import ServerSideRender from '@wordpress/server-side-render';

/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-block-editor/#useblockprops
 */
import { useBlockProps, InspectorControls } from '@wordpress/block-editor';

/**
 * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
 * Those files can contain any CSS code that gets applied to the editor.
 *
 * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
 */

import {
	TextControl,
	PanelBody,
	PanelRow,
	Placeholder,
} from '@wordpress/components';

import { code } from '@wordpress/icons';
import metadata from './block.json';
import './editor.scss';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-edit-save/#edit
 *
 * @return {WPElement} Element to render.
 */
export default function Edit( { attributes, setAttributes } ) {
	const blockProps = useBlockProps( {
		className: 'gradio-block',
	} );

	const isEditScreen = window.location.href.includes('wp-admin') && window.location.href.includes('action=edit');

	const { link, version } = attributes;

	const onChangeLink = ( newLink ) => {
		setAttributes( { link: newLink } );
	};

	const onChangeVersion = ( newVersion ) => {
		setAttributes( { version: newVersion } );
	};

	return (
		<>
			<InspectorControls>
				<PanelBody
					title={ __( 'Settings', 'dynamic-block' ) }
					initialOpen={ true }
				>
					<PanelRow>
						<fieldset>
							<TextControl
								label={ __( 'Embed Link', 'dynamic-block' ) }
								value={ link }
								onChange={ onChangeLink }
								help={ __(
									'Embed Link',
									'dynamic-block'
								) }
							/>
						</fieldset>
					</PanelRow>
					<PanelRow>
						<fieldset>
							<TextControl
								label={ __( 'Version', 'dynamic-block' ) }
								value={ version }
								onChange={ onChangeVersion }
								help={ __(
									'Gradio Version',
									'dynamic-block'
								) }
							/>
						</fieldset>
					</PanelRow>
				</PanelBody>
			</InspectorControls>

			<div { ...blockProps }>
				{ isEditScreen && (
					<Placeholder
						label="Gradio Placeholder"
						instructions='Preview is not available. Please check on the real page.'
						icon = { code }
					/>
				) }
				<ServerSideRender
					block={ metadata.name }
					attributes={ attributes }
				/>
			</div>
		</>
	);
}